LayoutBulkAlloc

Struct LayoutBulkAlloc 

pub struct LayoutBulkAlloc<B = System>
where B: GlobalAlloc,
{ /* private fields */ }
LayoutBulkAlloc is an implementation of GlobalAlloc.

This struct owns a cache for a specified layout.

Method alloc and dealloc check whether the required Layout fits the cache or not. If the Layout does not fit the cache, the methods delegate the request to the backend; otherwise, dealloc stores the passed pointer into the cache, and alloc dispatches and returns a pointer from the cache.

See alloc and dealloc for the details.

Instance drop releases all the cached memory. All the pointers allocated via the instance will be invalid after then. Accessing such a pointer may lead to memory unsafety even if the pointer itself is not deallocated.

Safety

The allocated pointers via LayoutBulkAlloc will be invalid after the instance is dropped. Accessing such a pointer may lead to memory unsafety even if the pointer itself is not deallocated.

Implementations

Source

impl<B> LayoutBulkAlloc<B>
where B: GlobalAlloc,

pub fn new(layout: Layout, backend: B) -> Self

Creates a new instance.